#PyDaSt

>*Pydast is currently in planning and development stage
>Multiple improvements and breaking changes can come until stable release

Short for Python Data Structures, Pydast is a powerful python module providing a bunch of efficient and method-rich distribution of Data Structures not already pre-built into python.
Functionalities to retrieve abstract data are also provided in order to make this much more flexible for all purpose needs.
In some cases, abstraction is kept low in order to provide maximal Control

##Available Structures

A list of Structures available (or planned to be made available) in the package is as under:

|Structures        | Info |
|------------------|------|
|singly            |  A Singly Linked List Data Structure |
|doubly            |  A Doubly Linked List Data Structure |
|maxHeap           |  A Max Heap  |
|minHeap           |  A Min Heap   |
|Disjoint_Set      |  A Disjoint_Set  |
|Trie              |  A Trie  |
|Stack             |  A Stack  |
|Queue             |  A Queue  |
|BinaryIndexedTree |  A Binary Indexed Tree  |

More Info can be found at [Pydast.org](https://pydast.org)


#Usage

All the structures are defined as classes 


